/*
 *  MOST:  window.h
 *
 *  Modified for C SWING and GOPHER compatibility by Foteos Macrides
 *                                                MACRIDES@SCI.WFEB.EDU
 */

#ifndef _DAVIS_WINDOW_H_
#define _DAVIS_WINDOW_H_
#include "buffer.h"

struct Window_Type
  {
      unsigned char *beg_pos;   /* buffer pos of top line */
      int beg_line;             /* line number of top */
      int curs_line;            /* line number of curs pos */
      int curs_col;             /* column number of curs pos */
      unsigned char *curs_pos;  /* pos of curs pos */
      int col;                  /* column offset */
      int n_lines;              /* number of lines of buffer (mode dependent) */
      int top;                  /* screen location of top */
      int bot;                  /* screen location of bot */
      int display;              /* value of SELECTIVE_I_DISPLAY */
      char *status;             /* status line */
      Buffer *buf;              /* buffer structure in window */
      struct Window_Type *next; /* next window */
      struct Window_Type *prev; /* prev window */
      int flags;                /* Squeeze lines, etc.. */
      int lock;                 /* true if locked */
  };
typedef struct Window_Type Window;

extern Window *WIN;
extern Window *TOP_WIN;
extern int COLUMN;
extern int CURS_ROW;
extern int CURS_COL;
extern unsigned char *CURS_POS;

extern void most_message(char *, int);
extern void exit_minibuffer();
extern void put_message();
extern int read_from_minibuffer(char *, char *);
extern void clear_minibuffer();
extern void update_window(int);  /* moves window to have arg lines on the top */
extern void update_windows(int);
extern void redraw_window();     /* redraws window updating the structure     */
extern void save_win_flags(Window *);
extern void window_buffer();
extern void clear_window();
extern void init_display();
extern void reset_display();
extern void update_status(int);
extern int split_window();
extern void two_windows();
extern void one_window();
extern void set_window(Window *);
extern void free_window_buffer();
extern void delete_window();
extern void redraw_display();
extern void toggle_lock();
extern void other_window(int);
#endif
